@@ -4,12 +4,12 @@ import ctypes
 import numba
 import numpy as np
 
-from numba_mpi.common import _MPI_Comm_World_ptr, _MpiStatusPtr, argtypes, libmpi
+from numba_mpi.common import _MPI_Comm_World_ptr, _MpiStatusPtr, libmpi, send_recv_args
 from numba_mpi.utils import _mpi_addr, _mpi_dtype
 
 _MPI_Recv = libmpi.MPI_Recv
 _MPI_Recv.restype = ctypes.c_int
-_MPI_Recv.argtypes = argtypes + [
+_MPI_Recv.argtypes = send_recv_args + [
     _MpiStatusPtr,
 ]
 
