@@ -1,4 +1,5 @@
 # pylint: disable=missing-function-docstring,missing-class-docstring,missing-module-docstring
+import numba
 import numpy as np
 import pytest
 
@@ -7,8 +8,14 @@ from tests.common import MPI_SUCCESS, data_types
 from tests.utils import get_random_array
 
 
+@numba.njit()
+def jit_bcast(data, root):
+    return mpi.bcast(data, root)
+
+
+@pytest.mark.parametrize("bcast", (jit_bcast.py_func, jit_bcast))
 @pytest.mark.parametrize("data_type", data_types)
-def test_bcast_np_array(data_type):
+def test_bcast_np_array(data_type, bcast):
     root = 0
     data = np.empty(5, data_type).astype(dtype=data_type)
     datatobcast = get_random_array(5, data_type).astype(dtype=data_type)
@@ -16,7 +23,7 @@ def test_bcast_np_array(data_type):
     if mpi.rank() == root:
         data = datatobcast
 
-    status = mpi.bcast(data, root)
+    status = bcast(data, root)
 
     assert status == MPI_SUCCESS
 
@@ -36,6 +43,5 @@ def test_bcast_string(stringtobcast):
         data = datatobcast
 
     status = mpi.bcast(data, root)
-
     assert status == MPI_SUCCESS
     assert str(data) == str(datatobcast)
