@@ -4,6 +4,6 @@ import pytest
 import numba_mpi as mpi
 
 
-@pytest.mark.parametrize("sut", [mpi.initialized, mpi.initialized.py_func])
+@pytest.mark.parametrize("sut", (mpi.initialized, mpi.initialized.py_func))
 def test_init(sut):
     assert sut()
